@@ -21,6 +21,7 @@ import (
 
 	"gopkg.in/yaml.v3"
 
+	kubeconfigutil "github.com/danielfoehrkn/kubeswitch/pkg/util/kubectx_copied"
 	"github.com/danielfoehrkn/kubeswitch/types"
 )
 
@@ -77,3 +78,45 @@ func ExpandEnv(path string) string {
 	path = strings.ReplaceAll(path, "~", "$HOME")
 	return os.ExpandEnv(path)
 }
+
+// GetCurrentContext returns "current-context" value of current kubeconfig
+func GetCurrentContext() (string, error) {
+	kc, err := kubeconfigutil.LoadCurrentKubeconfig()
+	if err != nil {
+		return "", err
+	}
+	currCtx := kc.GetCurrentContext()
+	if currCtx == "" {
+		return "", fmt.Errorf("current-context is not set")
+	}
+	return currCtx, nil
+}
+
+func SliceFindIndex[T string | int](slice []T, search T) int {
+	for k, v := range slice {
+		if v == search {
+			return k
+		}
+	}
+	return -1
+}
+
+func getAdditionalArgs() []string {
+	additionalArgsIndex := SliceFindIndex(os.Args, "--")
+	var additionalArgs []string
+	if additionalArgsIndex > 0 {
+		additionalArgs = os.Args[additionalArgsIndex+1:]
+	}
+	return additionalArgs
+}
+
+func SplitAdditionalArgs(args *[]string) []string {
+	additionalArgs := getAdditionalArgs()
+	length := len(additionalArgs)
+	if length > 0 {
+		tmp := *args
+		tmp = tmp[0 : len(*args)-length]
+		*args = tmp
+	}
+	return additionalArgs
+}
