@@ -24,7 +24,7 @@ import (
 type StoreKind string
 
 // ValidStoreKinds contains all valid store kinds
-var ValidStoreKinds = sets.NewString(string(StoreKindVault), string(StoreKindFilesystem), string(StoreKindGardener), string(StoreKindGKE), string(StoreKindAzure), string(StoreKindEKS), string(StoreKindRancher))
+var ValidStoreKinds = sets.NewString(string(StoreKindVault), string(StoreKindFilesystem), string(StoreKindGardener), string(StoreKindGKE), string(StoreKindAzure), string(StoreKindEKS), string(StoreKindRancher), string(StoreKindOVH), string(StoreKindScaleway), string(StoreKindDigitalOcean))
 
 // ValidConfigVersions contains all valid config versions
 var ValidConfigVersions = sets.NewString("v1alpha1")
@@ -44,6 +44,12 @@ const (
 	StoreKindEKS StoreKind = "eks"
 	// StoreKindRancher is an identifier for the Rancher store
 	StoreKindRancher StoreKind = "rancher"
+	// StoreKindOVH is an identifier for the OVH store
+	StoreKindOVH StoreKind = "ovh"
+	// StoreKindScaleway is an identifier for the Scaleway store
+	StoreKindScaleway StoreKind = "scaleway"
+	// StoreKindDigitalOcean is an identifier for the Azure store
+	StoreKindDigitalOcean StoreKind = "digitalocean"
 )
 
 type Config struct {
@@ -62,7 +68,11 @@ type Config struct {
 	// default: true
 	// + optional
 	ShowPreview *bool `yaml:"showPreview"`
-	// RefreshIndexAfter is the global default for how how often
+	// ExecShell configures the shell to be used for switch exec -- "command"
+	// If a shell (bash, zsh, sh) is provided, the command is executed like so
+	// --> bash -c "your_command"
+	ExecShell *string `yaml:"execShell"`
+	// RefreshIndexAfter is the global default for how often
 	// the index for this kubeconfig store shall be refreshed.
 	// Not setting this field will cause kubeswitch to not use an index
 	// Can be overridden in the individual kubeconfig store configuration
@@ -85,7 +95,7 @@ type KubeconfigStore struct {
 	// KubeconfigName defines how the kubeconfig is identified in the backing store
 	// For the Filesystem store, this is the name of the file that contains the kubeconfig
 	// For the Vault store, this is the secret key
-	// For the Gardener store this field is not used
+	// For other stores this field is not used
 	// + optional
 	KubeconfigName *string `yaml:"kubeconfigName"`
 	// Paths contains the paths to search for in the backing store
@@ -226,3 +236,17 @@ type StoreConfigRancher struct {
 	// RancherToken is the token used to authenticate against the Rancher API, format: token-12abc:bmjlzslas......x4hv5ptc29wt4sfk
 	RancherToken string `yaml:"rancherToken"`
 }
+
+type StoreConfigOVH struct {
+	OVHApplicationKey    string `yaml:"application_key"`
+	OVHApplicationSecret string `yaml:"application_secret"`
+	OVHConsumerKey       string `yaml:"consumer_key"`
+	OVHEndpoint          string `yaml:"endpoint"`
+}
+
+type StoreConfigScaleway struct {
+	ScalewayOrganizationID string `yaml:"organization_id"`
+	ScalewayAccessKey      string `yaml:"access_key"`
+	ScalewaySecretKey      string `yaml:"secret_key"`
+	ScalewayRegion         string `yaml:"region"`
+}
